pub fn render(sources: &SourceMap, diagnostic: &Diagnostic) -> StringExpand description
Renders a diagnostic as plain text with a source excerpt.
pub fn render(sources: &SourceMap, diagnostic: &Diagnostic) -> StringRenders a diagnostic as plain text with a source excerpt.